@@ -59,6 +59,7 @@ void weaver_rest(long nanoseconds){
   fps = 1000000 / (1000000 * (current_time.tv_sec - _b_frame.tv_sec) + current_time.tv_usec - _b_frame.tv_usec);
   if(fps == 0) fps = 1;
   XdbeSwapBuffers(_dpy, &info, 1);
+  XSync(_dpy, False);
 }
 
 
@@ -373,7 +374,7 @@ void film_fullpolygon(struct vector4 *camera, struct vector2 *polygon,
   }
   else{  
     XSetForeground(_dpy, _gc, color);
-    XFillPolygon(_dpy, _w, _gc, points, number_of_points, Complex, 
+    XFillPolygon(_dpy, window -> pix, _gc, points, number_of_points, Complex, 
                  CoordModeOrigin);
   }
   free(points);
